require(AlgDesign) 
installed.packages(AlgDesign)

# EXAMPLE 1
# A quadratic polynomial in three variables. The resulting D will be about 0.46.
# This may be compared with a standard central composite design obtained from
# rows 1,3,5,7,9,11,13,15,17,19,21,23,25,27 of dat, which has a D value of 0.46.
# The central composite design seems to be the optimal design for all three criteria.

dat<-gen.factorial(levels=3,nVars=3,varNames=c("A","B","C"))
dat

desD<-optFederov(~quad(A,B,C),dat,nTrials=10,eval=TRUE)
desD
desA<-optFederov(~quad(.),dat,nTrials=14,eval=TRUE,crit="A")
desA
desI<-optFederov(~quad(.),dat,nTrials=14,eval=TRUE,crit="I")
desI

# This is not the case for A or D. For A and D, the support points are the points
# of the grid with the three levels above. Points not on this grid move
# the criteria in a non-optimal direction; hence, the enlarging space has no effect.


# EXAMPLES 2
# Standard designs are usually optimal designs. If nTrials is set to that for
# a standard design, and if nRepeats is large enough, the standard design will
# often be found For example, a half replicate of a 2^4 will be obtained by the
# following.

dat<-gen.factorial(levels=2,nVars=3,varNames=c("A","B","C"))
desH<-optFederov(~.,dat,8)
desH

# A third replicate of a 3^3 will be obtained by the following:

dat<-gen.factorial(levels=3,nVars=3,factor=1:3)
dat
desT<-optFederov(~.,dat,9)
desT

# An orthogonal design similar to a 12 run Plackett-Burman design can be
# created by the following.

dat<-gen.factorial(levels=2,nVars=11,varNames=c("A","B","C","D","E","F","G","H","J","K","L"))
dat
desPB<-optFederov(~.,dat,12,nRepeats=20)
desPB




# The above calculation is numerically difficult for the A and I criteria,
# and nRepeats=100 or more may be needed.
# It is instructive to examine a case in which the standard design is not found.
# The following is an attempt to create a Latin square design. It is not always successful.

lv<-factor(1:5)
dat<-expand.grid(A=lv,B=lv,C=lv)
desL<-optFederov(~.,dat,nTrials=25,nRep=100)


# Blocking the design for a quadratic polynomial in three variables into two
# seven trial blocks:

dat<-gen.factorial(3,3,varNames=c("A","B","C"))

desD<-optFederov(~quad(.),dat,nTrials=14,eval=TRUE) # Choose an optimum 14 trail design.
optBlock(~quad(.),desD$design,c(7,7))

# Letting optBlock() search the dat candidate list instead of first choosing a
# 14 trial design.

optBlock(~quad(.),dat,c(7,7))

# A block design for 7 treatments in 7 blocks of size 3. Note how withinData
# is recycled to fill out the blocksize requirements.

BIB<-optBlock(~.,withinData=factor(1:7),blocksizes=rep(3,7))

# This is a balanced incomplete block design as may be seen from:
crossprod(table(BIB$rows,c(rep(1:7, rep(3,7)))))

# A partially balanced incomplete block design with two associate classes:
tr<-factor(1:9)
PBIB<-optBlock(~.,withinData=tr,blocksizes=rep(3,9))
crossprod(table(PBIB$rows,c(rep(1:9, rep(3,9)))))

# Two fractions of a 2^(4-1).
dat<-gen.factorial(2,4)
od<-optBlock(~.,dat,c(8,8))

# The blocks are not themselves orthogonal even though the entire design is optimal.
bk<-data.matrix(od$Blocks$B1)
t(bk)%*%bk

# Better blocks may be obtained as follows, but note that they are not generally
# the fractions that would be obtained by confounding the third order interaction.
od<-optBlock(~.,dat,c(8,8),criterion="Dpc",nR=10)
bk<-data.matrix(od$Blocks$B1)
t(bk)%*%bk
